"""Top-level package for ColabHost."""

__author__ = """Puneetha Pai"""
__email__ = "puneethapai29@gmail.com"
__version__ = "0.1.5"

from .colab_host import Host, SimpleHttpServer, JupyterNotebook, JupyterLab
